#ifndef _PCIE_COMMON_H
#define _PCIE_COMMON_H

typedef struct _THROUGHPUT_DATA
{
unsigned int Ch0Thruput;
unsigned int Ch1Thruput;

} THROUGHPUT_DATA;

typedef struct _ADC_STATS_RAW
{
int Stat_therm;
int Stat_3v3aux;
int Stat_12v;
int Stat_3v3;
int Stat_12vpsu;
int Stat_5vpsu;

int Avg_1;
int Avg_2;
int Avg_3;
int Avg_4;
}
ADC_STATS_RAW;


typedef struct _ADC_STATS
{
double flStat_therm;
double flStat_3v3aux;
double flStat_12v;
double flStat_3v3;
double flStat_12vpsu;
double flStat_5vpsu;
}
ADC_STATS;

typedef struct _DEBUG_REG_VALS
{
int AAW_CHAN;
int AAW_ADDRINT;
int AAW_ADDR;
int ADW_CHAN;
int ADR_CHAN;
int AAR_CHAN;
int AAR_GEN;
int AAR_ADDRINT;

} DEBUG_REG_VALS;


#define PCIE_THERM_MIN 0.0f
#define PCIE_THERM_MAX 90.0f
#define PCIE_12V_MIN 10.8f
#define PCIE_12V_MAX 13.2f
#define PCIE_3V3_MIN 2.97f
#define PCIE_3V3_MAX 3.63f
#define PCIE_3V3AUX_MIN PCIE_3V3_MIN
#define PCIE_3V3AUX_MAX PCIE_3V3_MAX
#define PCIE_12VPSU_MIN PCIE_12V_MIN
#define PCIE_12VPSU_MAX PCIE_12V_MAX
#define PCIE_5VPSU_MIN 4.5f
#define PCIE_5VPSU_MAX 5.5f

#define PM_PCIE_MAGIC_NUM 'P'

//Using IOCTL names to try and stay semi consistant with the windows driver 
#define IOCTL_IGL2_LEDCTL 		_IOWR(PM_PCIE_MAGIC_NUM, 1, int)
#define IOCTL_IGL2_GET_THROUGHPUT	_IOR(PM_PCIE_MAGIC_NUM, 2, THROUGHPUT_DATA)
#define IOCTL_IGL2_SET_READ_MODE	_IOW(PM_PCIE_MAGIC_NUM, 3, int)
#define IOCTL_IGL2_SET_ADC_CH		_IOW(PM_PCIE_MAGIC_NUM, 4, int)
#define IOCTL_IGL2_SET_WRITEMODE 	_IOW(PM_PCIE_MAGIC_NUM, 5, int)
#define IOCTL_IGL2_CLEAR_DMA_REG	_IO(PM_PCIE_MAGIC_NUM, 6)
#define IOCTL_IGL2_GETCB 		_IOR (PM_PCIE_MAGIC_NUM, 7, int)
#define IOCTL_IGL2_SET_XFER_SIZE	_IOW(PM_PCIE_MAGIC_NUM, 8, int)
#define IOCTL_IGL2_GET_CONFIG 		_IOR (PM_PCIE_MAGIC_NUM, 9, int)
#define IOCTL_IGL2_READ_LSRAM_REG	_IOR (PM_PCIE_MAGIC_NUM, 10, int)
#define IOCTL_IGL2_READ_REG 		_IOR (PM_PCIE_MAGIC_NUM, 11, int)
#define IOCTL_IGL2_ACCESS_CONFIG_SPACE	_IO(PM_PCIE_MAGIC_NUM, 12)
#define IOCTL_IGL2_GET_ADC_STATS	_IOR(PM_PCIE_MAGIC_NUM, 13, ADC_STATS_RAW)
#define IOCTL_IGL2_SET_VOLT_TOL		_IOW(PM_PCIE_MAGIC_NUM, 14, int)
#define IOCTL_IGL2_RESET_STATS_REG	_IO(PM_PCIE_MAGIC_NUM, 15)
#define IOCTL_IGL2_GET_DEBUG_VALS	_IOR(PM_PCIE_MAGIC_NUM, 16, DEBUG_REG_VALS)
#define IOCTL_IGL2_SET_CLOCK		_IOW(PM_PCIE_MAGIC_NUM, 17, int)

#define PCIE_READ_ADC_MODE	2 //ADC -> PCIE
#define PCIE_READ_LSRAM_MODE	6 //LSRAM -> PCIE

#define PCIE_WRITE_BENCHMARK_MODE	1 //PCIE -> LSRAM
#define PCIE_WRITE_LOOPBACK_MODE	2 //PCIE - > LSRAM -> PC

#define PCIE_ADC_TEMP_SENSOR                    0
#define PCIE_ADC_12V_PCIE_AND_3V3_PCIE 	        2
#define PCIE_ADC_12V_PCIE_AND_12V_MOLEX		3
#define PCIE_ADC_5V_MOLEX_AND_12V_MOLEX		4
#define PCIE_ADC_3V_AUX                         5
#define PCIE_ADC_NUM_OPTIONS			5

//Clock options
#define CLOCK_LOW	0
#define CLOCK_HIGH	1

//For reading and converting ADC values
#define PCIE_NUM_ADC_SOURCES 2

#define PCIE_NUM_ADC_READINGS 2048
#define PCIE_NOVALUE -1001

#define UPPERWORD(statOut) statOut >> 16
#define LOWERWORD(statOut) statOut & 0xFFFF

#define RAWGAIN 4095 * 5
#define VOLTS2TEMP(v) (v-0.5)/0.01

typedef enum _BENCHMARK_TYPE
{
BENCHMARK_WO=0,
BENCHMARK_RO,
BENCHMARK_RTW
} BENCHMARK_TYPE;

typedef enum _BENCHMAK_MODE
{
BENCHMARK_READ = 0,
BENCHMARK_WRITE
} BENCHMARK_MODE;		

typedef struct _VALUE_RANGE
{
  double flMin;
  double flAvg;
  double flMax;
} VALUE_RANGE;

typedef struct _CONFIG_INFO
{
	unsigned int linkWidth;
	unsigned int adcCh;
	unsigned int xferSize;
	unsigned int xferBufferSize;
	unsigned int readMode;
	unsigned int writeMode;
	unsigned int ledStatus;
	unsigned int sn0;
	unsigned int sn1;
	unsigned int sn2;
	unsigned int sn3;
	unsigned int fwVersion;
	unsigned int pcieVer;
} CONFIG_INFO;

#endif //_PCIE_COMMON_H